<?php
/**
 * Featured options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add featured section
$wp_customize->add_section( 'yule_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','yule-pro' ),
	'description'       => esc_html__( 'Featured options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// featured enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[featured_section_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['featured_section_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Enable', 'yule-pro' ),
	'section'           => 'yule_pro_featured_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// featured content type control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'yule_pro_sanitize_select',
) );

$wp_customize->add_control( 'yule_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yule-pro' ),
	'section'           => 'yule_pro_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_pro_is_featured_section_enable',
	'choices'			=> yule_pro_featured_options(),
) );

// featured number control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'yule_pro_sanitize_number_range',
	'validate_callback' => 'yule_pro_validate_featured_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of featured posts', 'yule-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'yule-pro' ),
	'section'           => 'yule_pro_featured_section',
	'active_callback'   => 'yule_pro_is_featured_section_content_page',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['featured_count']; $i++ ) {
	// Show page drop-down setting and control
	$wp_customize->add_setting( 'yule_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'yule_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'yule_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Select Page %d', 'yule-pro' ), $i ),
		'section'        	=> 'yule_pro_featured_section',
		'active_callback' 	=> 'yule_pro_is_featured_section_content_page',
		'type'				=> 'dropdown-pages'
	) );
}


// featured section content type post setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[featured_content_post]', array(
	'sanitize_callback' => 'yule_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yule_pro_theme_options[featured_content_post]', array(
	'active_callback'	=> 'yule_pro_is_featured_section_content_post',
	'label'             => esc_html__( 'Input Post Id', 'yule-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max ten post ids allowed. ie: 11, 24, 34', 'yule-pro' ),
	'section'           => 'yule_pro_featured_section',
	'type'				=> 'text',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// featured section content type product setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[featured_content_product]', array(
	'sanitize_callback' => 'yule_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yule_pro_theme_options[featured_content_product]', array(
	'active_callback'	=> 'yule_pro_is_featured_section_content_product',
	'label'             => esc_html__( 'Input Product Id', 'yule-pro' ),
	'description'       => esc_html__( 'Simply hover product title on dashboard to see the Product ID. Max ten product ids allowed. ie: 11, 24, 34', 'yule-pro' ),
	'section'           => 'yule_pro_featured_section',
	'type'				=> 'text',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );
