<?php
/**
 * Latest options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add latest section
$wp_customize->add_section( 'yule_pro_latest_section', array(
	'title'             => esc_html__( 'Latest','yule-pro' ),
	'description'       => esc_html__( 'Latest options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// latest enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[latest_section_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['latest_section_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Enable', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// latest section title setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'yule-pro' ),
	'section'        	=> 'yule_pro_latest_section',
	'active_callback' 	=> 'yule_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[latest_title]', array(
		'selector'            => '#latest-products .section-header h2.section-title',
		'settings'            => 'yule_pro_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_latest_title_partial',
    ) );
}

// latest content type control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[latest_content_type]', array(
	'default'          	=> $options['latest_content_type'],
	'sanitize_callback' => 'yule_pro_sanitize_select',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_pro_is_latest_section_enable',
	'choices'			=> yule_pro_latest_options(),
) );


// latest number control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[latest_count]', array(
	'default'          	=> $options['latest_count'],
	'sanitize_callback' => 'yule_pro_sanitize_number_range',
	'validate_callback' => 'yule_pro_validate_latest_count',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'yule-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save.', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'active_callback'   => 'yule_pro_is_latest_section_count_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// latest Section content type post setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[latest_content_post]', array(
	'sanitize_callback' => 'yule_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_content_post]', array(
	'active_callback'	=> 'yule_pro_is_latest_section_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'yule-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. ie: 11, 24, 34', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'type'				=> 'text',
) );

// latest Section content type product setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[latest_content_product]', array(
	'sanitize_callback' => 'yule_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_content_product]', array(
	'active_callback'	=> 'yule_pro_is_latest_section_content_product',
	'label'             => esc_html__( 'Input Product Ids', 'yule-pro' ),
	'description'       => esc_html__( 'Simply hover product title on dashboard to see the Product ID. ie: 11, 24, 34', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'type'				=> 'text',
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'yule_pro_theme_options[latest_content_category]', array(
	'sanitize_callback' => 'yule_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Yule_Pro_Dropdown_Taxonomies_Control( $wp_customize,'yule_pro_theme_options[latest_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'yule-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'yule_pro_is_latest_section_content_category'
) ) );

// Add dropdown product category setting and control.
$wp_customize->add_setting(  'yule_pro_theme_options[latest_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Yule_Pro_Dropdown_Taxonomies_Control( $wp_customize,'yule_pro_theme_options[latest_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'yule-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'yule-pro' ),
	'section'           => 'yule_pro_latest_section',
	'type'              => 'dropdown-taxonomies',
	'taxonomy'          => 'product_cat',
	'active_callback'	=> 'yule_pro_is_latest_section_content_product_category'
) ) );

// latest btn label setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[latest_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[latest_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'yule-pro' ),
	'section'        	=> 'yule_pro_latest_section',
	'active_callback' 	=> 'yule_pro_is_latest_section_count_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[latest_btn_label]', array(
		'selector'            => '#latest-products .more-link a.btn-default',
		'settings'            => 'yule_pro_theme_options[latest_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_latest_btn_label_partial',
    ) );
}
