<?php
/**
 * Popular options
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

// Add popular section
$wp_customize->add_section( 'yule_pro_popular_section', array(
	'title'             => esc_html__( 'Popular','yule-pro' ),
	'description'       => esc_html__( 'Popular options.', 'yule-pro' ),
	'panel'             => 'yule_pro_front_page_panel',
) );

// popular enable control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[popular_section_enable]', array(
	'sanitize_callback' => 'yule_pro_sanitize_switch_control',
	'default'          	=> $options['popular_section_enable'],
) );

$wp_customize->add_control( new Yule_Pro_Switch_Control( $wp_customize, 'yule_pro_theme_options[popular_section_enable]', array(
	'label'             => esc_html__( 'Popular Enable', 'yule-pro' ),
	'section'           => 'yule_pro_popular_section',
	'on_off_label' 		=> yule_pro_switch_options(),
) ) );

// popular content type control and setting
$wp_customize->add_setting( 'yule_pro_theme_options[popular_content_type]', array(
	'default'          	=> $options['popular_content_type'],
	'sanitize_callback' => 'yule_pro_sanitize_select',
) );

$wp_customize->add_control( 'yule_pro_theme_options[popular_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'yule-pro' ),
	'section'           => 'yule_pro_popular_section',
	'type'				=> 'select',
	'active_callback' 	=> 'yule_pro_is_popular_section_enable',
	'choices'			=> yule_pro_popular_options(),
) );

// Show page drop-down setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[popular_content_page]', array(
	'sanitize_callback' => 'yule_pro_sanitize_page'
) );

$wp_customize->add_control( 'yule_pro_theme_options[popular_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'yule-pro' ),
	'section'        	=> 'yule_pro_popular_section',
	'active_callback' 	=> 'yule_pro_is_popular_section_content_page',
	'type'				=> 'dropdown-pages'
) );

// popular section content type post setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[popular_content_post]', array(
	'validate_callback' => 'yule_pro_validate_post_id',
	'sanitize_callback' => 'yule_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'yule_pro_theme_options[popular_content_post]', array(
	'active_callback'	=> 'yule_pro_is_popular_section_content_post',
	'label'             => esc_html__( 'Input Post Id', 'yule-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'yule-pro' ),
	'section'           => 'yule_pro_popular_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// popular section content type product setting and control.
$wp_customize->add_setting( 'yule_pro_theme_options[popular_content_product]', array(
	'validate_callback' => 'yule_pro_validate_post_id',
	'sanitize_callback' => 'yule_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'yule_pro_theme_options[popular_content_product]', array(
	'active_callback'	=> 'yule_pro_is_popular_section_content_product',
	'label'             => esc_html__( 'Input Product Id', 'yule-pro' ),
	'description'       => esc_html__( 'Please Input Valid Product Id. Simply hover product title on dashboard to see the Product ID.', 'yule-pro' ),
	'section'           => 'yule_pro_popular_section',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// popular btn label setting and control
$wp_customize->add_setting( 'yule_pro_theme_options[popular_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['popular_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yule_pro_theme_options[popular_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'yule-pro' ),
	'section'        	=> 'yule_pro_popular_section',
	'active_callback' 	=> 'yule_pro_is_popular_section_content_not_demo',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'yule_pro_theme_options[popular_btn_label]', array(
		'selector'            => '#popular-product .more-link a.btn-primary',
		'settings'            => 'yule_pro_theme_options[popular_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'yule_pro_popular_btn_label_partial',
    ) );
}
