<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function yule_pro_body_classes( $classes ) {
	$options = yule_pro_get_theme_options();

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add a class for typography
	$typography = (  $options['theme_typography'] == 'default' ) ? '' :  $options['theme_typography'];
	$classes[] = esc_attr( $typography );

	$body_typography = (  $options['body_theme_typography'] == 'default' ) ? '' :  $options['body_theme_typography'];
	$classes[] = esc_attr( $body_typography );

	// Add a class for layout
	$classes[] = esc_attr( $options['site_layout'] );

	// Add a class for sidebar
	$sidebar_position = yule_pro_layout();
	$sidebar = 'sidebar-1';

	if ( is_singular() ) {
		$sidebar = get_post_meta( get_the_id(), 'yule-pro-selected-sidebar', true );
		$sidebar = ! empty( $sidebar ) ? $sidebar : 'sidebar-1';
	}
	
	if ( is_active_sidebar( $sidebar ) && ! is_404() ) {
		$classes[] = esc_attr( $sidebar_position );
	} elseif( is_404() ) {
		$classes[] = is_active_sidebar( '404-page-sidebar' ) ? $sidebar_position : 'no-sidebar' ;
	} else {
		$classes[] = 'no-sidebar';
	}

	$classes[] = ( $options['menu_sticky'] ) ? 'sticky-menu' : '' ;

	return $classes;
}
add_filter( 'body_class', 'yule_pro_body_classes' );
