<?php
/**
 * Popular section
 *
 * @package Theme Palace
 * @subpackage Yule Pro
 * @since Yule Pro 1.0.0
 */
if ( ! function_exists( 'yule_pro_add_popular_section' ) ) :
    /**
    * Add popular section
    *
    *@since Yule Pro 1.0.0
    */
    function yule_pro_add_popular_section() {
    	$options = yule_pro_get_theme_options();
        // Check if popular is enabled on frontpage
        $popular_enable = apply_filters( 'yule_pro_section_status', true, 'popular_section_enable' );

        if ( true !== $popular_enable ) {
            return false;
        }
        // Get popular section details
        $section_details = array();
        $section_details = apply_filters( 'yule_pro_filter_popular_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular section now.
        yule_pro_render_popular_section( $section_details );
    }
endif;
add_action( 'yule_pro_primary_content', 'yule_pro_add_popular_section', 10 );

if ( ! function_exists( 'yule_pro_get_popular_section_details' ) ) :
    /**
    * popular section details.
    *
    * @since Yule Pro 1.0.0
    * @param array $input popular section details.
    */
    function yule_pro_get_popular_section_details( $input ) {
        $options = yule_pro_get_theme_options();

        // Content type.
        $popular_content_type  = $options['popular_content_type'];
        $content = array();
        switch ( $popular_content_type ) {
            case 'demo':
                $demo['title']      = esc_html__( 'White fur Jacket', 'yule-pro' );
                $demo['excerpt']    = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec dolor neque, ultrices cursus facilisis ut, finibus ut leo. Nunc vitae augue eget eros tristique euismod.', 'yule-pro' );
                $demo['price']		= sprintf( esc_html__( '%1$s150%2$s', 'yule-pro' ), '$<ins>', '</ins>' );
                $demo['image']		= get_template_directory_uri() . '/assets/uploads/post-01.jpg';
                $demo['url']		= '#';

                // Push to the main array.
                array_push( $content, $demo );
            break;

            case 'page':
                $page_id = ! empty( $options['popular_content_page'] ) ? $options['popular_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['popular_content_post'] ) ? $options['popular_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'product':
                $post_id = ! empty( $options['popular_content_product'] ) ? $options['popular_content_product'] : '';
                $args = array(
                    'post_type'         => 'product',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1, 
                    );
            break;

            default:
            break;
        }

        if ( in_array( $popular_content_type, array( 'page', 'post', 'product' ) ) ) {

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']     	= get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = get_the_excerpt();
                    $page_post['url']   	= get_the_permalink();
                    $page_post['image']		= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';
                    if ( class_exists( 'WooCommerce' ) && 'product' == $popular_content_type ):
                    	$product = new WC_Product( get_the_id() );
                    	$page_post['price'] = $product->get_price_html();
                	endif;

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular section content details.
add_filter( 'yule_pro_filter_popular_section_details', 'yule_pro_get_popular_section_details' );


if ( ! function_exists( 'yule_pro_render_popular_section' ) ) :
  /**
   * Start popular section
   *
   * @return string popular content
   * @since Yule Pro 1.0.0
   *
   */
   function yule_pro_render_popular_section( $content_details = array() ) {
        $options = yule_pro_get_theme_options();
        $popular_content_type  = $options['popular_content_type'];
        $btn_label = ! empty( $options['popular_btn_label'] ) ? $options['popular_btn_label'] : esc_html__( 'Shop Now', 'yule-pro' );

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>
        	<div id="popular-product" class="relative">
                <div class="wrapper">
                    <article <?php echo ! empty( $content['image'] ) ? 'class="has-featured-image"' : ''; ?>>
	                    <?php if ( ! empty( $content['image'] ) ) : ?>
	                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
	                        </div><!-- .featured-image -->
	                    <?php endif; ?>

                        <div class="entry-container">
                            <div class="entry-meta">
                                <span class="cat-links">
                                	<?php 
                                	if ( 'post' === $popular_content_type ) : 
                                		the_category( ', ', '', $content['id'] );
                                	elseif ( 'product' == $popular_content_type ) :
										$cats = get_the_terms( $content['id'], 'product_cat' ); 
										if ( ! empty( $cats ) ) :
											foreach ( $cats as $cat ) : ?>
												<a href="<?php echo esc_url( get_term_link( $cat->term_id ) ); ?>"><?php echo esc_html( $cat->name ); ?></a>
											<?php endforeach;
										endif;
									elseif ( 'demo' == $popular_content_type ) :
                                	?>
                                		<a href="#"><?php esc_html_e( 'Latest collection', 'yule-pro' ); ?></a>
                            		<?php endif; ?>
                            	</span>
                            </div>
                            <div class="featured-header">
                                <h2 class="featured-product-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </div><!-- .featured-header -->

                            <div class="featured-content">
                               	<?php echo wp_kses_post( $content['excerpt'] ); ?>
                            </div><!-- .featured-content -->
                            <?php if ( in_array( $popular_content_type , array( 'demo', 'product' ) ) ) : ?>
	                            <div class="featured-price">
	                                <span class="label"><?php esc_html_e( 'Price', 'yule-pro' ); ?>:</span>
	                                <span class="amount"><?php echo wp_kses_post( $content['price'] ); ?></span>
	                            </div><!-- .featured-price -->
	                        <?php endif; ?>

                            <div class="more-link">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $btn_label ); ?></a>
                            </div>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #featured-product -->
        <?php endforeach;
    }
endif;